@@ -1,4 +1,4 @@
-# Copyright (C) 2014-2021 all contributors <meta@public-inbox.org>
+# Copyright (C) all contributors <meta@public-inbox.org>
 # License: AGPL-3.0+ <https://www.gnu.org/licenses/agpl-3.0.txt>
 #
 # Used for displaying the HTML web interface.
@@ -142,6 +142,9 @@ $info
   <a
 href="$se_url">$se_url</a>
 $link</pre>
+
+  Be sure your reply has a <b>Subject:</b> header at the top and a blank line
+  before the message body.
 EOF
 }
 
@@ -426,7 +429,7 @@ sub stream_thread_i { # PublicInbox::WwwStream::getline callback
 
 sub stream_thread ($$) {
 	my ($rootset, $ctx) = @_;
-	$ctx->{-queue} = [ map { (0, $_) } @$rootset ];
+	@{$ctx->{-queue}} = map { (0, $_) } @$rootset;
 	PublicInbox::WwwStream::aresponse($ctx, 200, \&stream_thread_i);
 }
 
@@ -1189,7 +1192,7 @@ sub pagination_footer ($$) {
 		$next = $next ? "$next | " : '             | ';
 		$prev .= qq[ | <a\nhref="$latest">latest</a>];
 	}
-	"<hr><pre>page: $next$prev</pre>";
+	($next || $prev) ? \"<hr><pre>page: $next$prev</pre>" : \'';
 }
 
 sub paginate_recent ($$) {
@@ -1240,11 +1243,8 @@ sub paginate_recent ($$) {
 sub index_topics {
 	my ($ctx) = @_;
 	my $msgs = paginate_recent($ctx, 200); # 200 is our window
-	if (@$msgs) {
-		walk_thread(thread_results($ctx, $msgs), $ctx, \&acc_topic);
-	}
-	html_oneshot($ctx, dump_topics($ctx), \pagination_footer($ctx, '.'));
-
+	walk_thread(thread_results($ctx, $msgs), $ctx, \&acc_topic) if @$msgs;
+	html_oneshot($ctx, dump_topics($ctx), pagination_footer($ctx, '.'));
 }
 
 sub thread_adj_level {
